@@ -84,7 +84,7 @@ BasePlotWnd::BasePlotWnd(QWidget *parent,
 //! Destruct \c this BasePlotWnd instance.
 BasePlotWnd::~BasePlotWnd()
 {
-   qDebug();
+  //qDebug();
   writeSettings();
 }
 
@@ -125,7 +125,7 @@ BasePlotWnd::readSettings()
 void
 BasePlotWnd::closeEvent([[maybe_unused]] QCloseEvent *event)
 {
-  qDebug();
+  //qDebug();
   writeSettings();
   hide();
 }
@@ -145,7 +145,7 @@ BasePlotWnd::initialize()
   setWindowTitle(QString("mineXpert2 - %1").arg(m_title));
 
   // We do not want to destroy on close !!!
-  //setAttribute(Qt::WA_DeleteOnClose);
+  // setAttribute(Qt::WA_DeleteOnClose);
 
   // The default window icon.
   QString pixmap_file_name = ":/images/icons/32x32/minexpert2.png";
@@ -1335,7 +1335,7 @@ BasePlotWnd::plotCompositeWidgetForPlottable(QCPAbstractPlottable *plottable_p)
 void
 BasePlotWnd::plotRangesChanged(const pappso::BasePlotContext &context)
 {
-  // qDebug();
+  //qDebug() << "With context:" << context.toString();
 
   // Iterate in the list of composite widgets currently in this window, and
   // ask them to replot using the range if necessary.
@@ -1343,13 +1343,22 @@ BasePlotWnd::plotRangesChanged(const pappso::BasePlotContext &context)
   int which_plot_axis = 0;
 
   if(m_isLockedXRange)
-    which_plot_axis |= static_cast<int>(pappso::Axis::x);
+    {
+      which_plot_axis |= static_cast<int>(pappso::Axis::x);
+      //qDebug() << "Locked range:" << (int)which_plot_axis;
+    }
 
   if(m_isLockedYRange)
-    which_plot_axis |= static_cast<int>(pappso::Axis::y);
+    {
+      which_plot_axis |= static_cast<int>(pappso::Axis::y);
+      //qDebug() << "Locked range:" << (int)which_plot_axis;
+    }
 
   if(!which_plot_axis)
-    return;
+    {
+      //qDebug() << "Apparently no locked range.";
+      return;
+    }
 
   QCPRange x_axis_range(context.m_xRange.lower, context.m_xRange.upper);
   QCPRange y_axis_range(context.m_yRange.lower, context.m_yRange.upper);
@@ -1358,8 +1367,12 @@ BasePlotWnd::plotRangesChanged(const pappso::BasePlotContext &context)
     findChildren<BasePlotCompositeWidget *>("plotCompositeWidget");
   std::vector<BaseTracePlotCompositeWidget *> pinned_down_widgets;
 
+  //qDebug() << "The list of widget has size:" << widget_list.size();
+
   for(int iter = 0; iter < widget_list.size(); ++iter)
     {
+      //qDebug() << "Iterating in widget iter: " << iter;
+
       BasePlotCompositeWidget *widget_p = widget_list.at(iter);
 
       if(QObject::sender() == dynamic_cast<QObject *>(widget_p))
@@ -1367,7 +1380,7 @@ BasePlotWnd::plotRangesChanged(const pappso::BasePlotContext &context)
           // We do not want to ask that the emitter replots itself, which
           // would be nonsense.
 
-          // qDebug() << "This one is the sender.";
+          //qDebug() << "This one is the sender.";
           continue;
         }
 
@@ -1375,13 +1388,19 @@ BasePlotWnd::plotRangesChanged(const pappso::BasePlotContext &context)
       widget_p->mp_plotWidget->replotWithAxesRanges(
         x_axis_range, y_axis_range, static_cast<pappso::Axis>(which_plot_axis));
 
+      //qDebug() << "x_axis_range:" << x_axis_range.lower << "-"
+               //<< x_axis_range.upper << "y_axis_range:" << y_axis_range.lower
+               //<< "-" << y_axis_range.upper;
+
       // We also need to update the context so that when we focus another plot
       // widget, there is no jump in the plot, the plot was moved and has
       // recorded the new ranges in the context and thus "start from there" when
       // the trace is somehow panned or whatever. This fixes an issue reported
-      // by Kevin Hooijschuur. 
+      // by Kevin Hooijschuur.
       widget_p->mp_plotWidget->updateContextXandYAxisRanges();
     }
+
+  //qDebug() << "Now returning from the function.";
 }
 
 
@@ -1461,8 +1480,8 @@ BasePlotWnd::fillInQualifiedMassSpectraVector(
 
   if(qualified_mass_spectra_sp->size())
     {
-      qDebug() << "The vector of qualified spectra is not empty. Returning "
-                  "with no modification.";
+      //qDebug() << "The vector of qualified spectra is not empty. Returning "
+                  //"with no modification.";
 
       return qualified_mass_spectra_sp->size();
     }
@@ -1484,17 +1503,17 @@ BasePlotWnd::fillInQualifiedMassSpectraVector(
   if(!integration)
     qFatal("Programming error.");
 
-  qDebug() << "Filling-in mass spectra for RT range: " << range_pair.first
-           << "-" << range_pair.second;
+  //qDebug() << "Filling-in mass spectra for RT range: " << range_pair.first
+           //<< "-" << range_pair.second;
 
-  std::size_t added_rt_mass_spectra =
-    ms_run_data_set_csp->getMsRunDataSetTreeCstSPtr()
-      ->addDataSetQualMassSpectraInsideDtRtRange(range_pair.first,
-                                                 range_pair.second,
-                                                 *qualified_mass_spectra_sp,
-                                                 pappso::DataKind::rt);
+  //std::size_t added_rt_mass_spectra =
+    //ms_run_data_set_csp->getMsRunDataSetTreeCstSPtr()
+      //->addDataSetQualMassSpectraInsideDtRtRange(range_pair.first,
+                                                 //range_pair.second,
+                                                 //*qualified_mass_spectra_sp,
+                                                 //pappso::DataKind::rt);
 
-  qDebug() << "Added RT mass spectra:" << added_rt_mass_spectra;
+  //qDebug() << "Added RT mass spectra:" << added_rt_mass_spectra;
 
   // Now see if we can remove some mass spectra on the basis of DT values.
 
@@ -1507,20 +1526,20 @@ BasePlotWnd::fillInQualifiedMassSpectraVector(
   // the mass spectral acquisitions involved ion mobility.
   if(integration)
     {
-      qDebug()
-        << "Detected DT integration, removing mass spectra outside DT range: "
-        << range_pair.first << "-" << range_pair.second;
+      //qDebug()
+        //<< "Detected DT integration, removing mass spectra outside DT range: "
+        //<< range_pair.first << "-" << range_pair.second;
 
-      std::size_t removed_mass_spectra =
-        ms_run_data_set_csp->getMsRunDataSetTreeCstSPtr()
-          ->removeDataSetQualMassSpectraOutsideDtRtRange(
-            range_pair.first,
-            range_pair.second,
-            *qualified_mass_spectra_sp,
-            pappso::DataKind::dt);
+      //std::size_t removed_mass_spectra =
+        //ms_run_data_set_csp->getMsRunDataSetTreeCstSPtr()
+          //->removeDataSetQualMassSpectraOutsideDtRtRange(
+            //range_pair.first,
+            //range_pair.second,
+            //*qualified_mass_spectra_sp,
+            //pappso::DataKind::dt);
 
-      qDebug() << "Number of mass spectra removed on the basis of DT:"
-               << removed_mass_spectra;
+      //qDebug() << "Number of mass spectra removed on the basis of DT:"
+               //<< removed_mass_spectra;
     }
 
   // At this point we need to really check which of the remaining spectra are
