@@ -215,7 +215,7 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
   context.m_selectionPolygon.rangeX(x_range_start, x_range_end);
 
-  qDebug() << "X axis range:" << x_range_start << "-" << x_range_end;
+  //qDebug() << "X axis range:" << x_range_start << "-" << x_range_end;
 
   if(x_range_start < 0 && x_range_end < 0)
     return;
@@ -225,7 +225,7 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
   context.m_selectionPolygon.rangeY(y_range_start, y_range_end);
 
-  qDebug() << "Y axis range:" << y_range_start << "-" << y_range_end;
+  //qDebug() << "Y axis range:" << y_range_start << "-" << y_range_end;
 
   if(y_range_start < 0 && y_range_end < 0)
     return;
